@@ -866,7 +866,7 @@ class AggregatePlot(Report, id="aggplot"):
                 groupby = dataframe.groupby(groupattrs)
                 sliceop = SLICE_OPS[self.sliceop]
                 dataframe = sliceop(groupby)
-                dataframe.reset_index()
+                dataframe.reset_index(inplace=True)
 
             if self._summary is None:
                 self._summary = summarize(
@@ -885,7 +885,7 @@ class AggregatePlot(Report, id="aggplot"):
             title = "\n".join(self.titleformat) % formatdict
             title = replace_keywords(title, keyword_replacements)
             plt.rc("text", usetex=self.usetex)
-            self._figure.suptitle(title, fontsize=self.fontsize)
+            self._figure.suptitle(title, fontsize=self.fontsize * 0.9)
             axes: plt.Axes = self._figure.subplots(nrows=1, ncols=len(self.plot))
             if len(self.plot) == 1:
                 axes = np.array([axes])
